<template>
  <a-modal
    :title="title"
    :width="1050"
    :visible="visible"
    :maskClosable="false"
    @ok="handleOk"
    cancelText="关闭"
    @cancel="handleCancel"
  >

    <a-spin :spinning="confirmLoading">
      <a-form :form="form">

        <!-- title="工艺路径基本信息" -->
        <a-row :span="24">
          <a-col :span="12">
            <a-form-item
              label="工艺参数模板编码"
              :labelCol="labelCol"
              :wrapperCol="wrapperCol"
            >
              <a-input
                allowClear
                :disabled="codeDisable"
                :placeholder="disableSubmit?'':'请输入工艺参数模板编码'"
                v-decorator="[ 'num', validatorRules.num]"
              />
            </a-form-item>
          </a-col>
          <a-col :span="12" >
            <a-form-item
              label="工艺参数模板名称"
              :labelCol="labelCol"
              :wrapperCol="wrapperCol"
            >
              <a-input
                allowClear
                :disabled="disableSubmit"
                :placeholder="disableSubmit?'':'请输入工艺参数模板名称'"
                v-decorator="[ 'name', validatorRules.name]"
              />
            </a-form-item>
          </a-col>
        </a-row>

        <a-row :span="24">
          <a-col :span="12">
            <a-form-item
              label="备注"
              :labelCol="labelCol"
              :wrapperCol="wrapperCol"
            >
              <a-textarea
                allowClear
                :disabled="disableSubmit"
                :placeholder="disableSubmit?'':'请输入备注'"
                v-decorator="[ 'remark', validatorRules.remark]"
              />
            </a-form-item>
          </a-col>
        </a-row>

      </a-form>
    </a-spin>
    <a-button
      type="primary"
      :style="{ marginRight: '8px',marginBottom:'8px' }"
      @click="selectProcessParameters()"
    >工艺参数选择</a-button>
    <a-table
      ref="table"
      bordered
      size="middle"
      :columns="columns"
      :dataSource="dataSource"
    >
      <span
        slot="action"
        slot-scope="text, record, index"
      >
        <a-popconfirm
          title="确定删除吗?"
          @confirm="() => handleDelete(text,record, index)"
        >
          <a>删除</a>
        </a-popconfirm>
      </span>
    </a-table>
    <template slot="footer">
      <a-button
        :style="{marginRight: '8px'}"
        @click="handleCancel()"
      >
        关闭
      </a-button>

      <a-button
         @click="handleOk()"
        type="primary"
         :loading="confirmLoading"
      >确定</a-button>
    </template>
    <j-select-process-parameters-modal ref="processParametersModalForm"></j-select-process-parameters-modal>
  </a-modal>

</template>

<script>
import { getAction, postAction, requestPut } from '@/api/manage'
import pick from 'lodash.pick'
import JMultiSelectTag from '@/components/dict/JMultiSelectTag'
import { duplicateCheck } from '@/api/api'
import Tooltip from 'ant-design-vue/es/tooltip'
import JSelectProcessParametersModal from './JSelectProcessParametersModal'

export default {
  name: "ProcessParametersTemplateModel",
  components: {
    JMultiSelectTag,
    Tooltip,
    JSelectProcessParametersModal
  },
  data() {
    return {
      columns: [
        {
          title: '#',
          dataIndex: '',
          key: 'rowIndex',
          align: 'center',
          customRender: function (t, r, index) {
            return parseInt(index) + 1
          },
          width: 50,
        },
        {
          title: '工艺参数编码',
          align: "center",
          dataIndex: 'processParametersNum',
          scopedSlots: {
            customRender: 'processParametersNum'
          },
        },
        {
          title: '工艺参数名称',
          align: "center",
          dataIndex: 'processParametersName',
          scopedSlots: {
            customRender: 'processParametersName'
          },
        },
        {
          title: '工艺参数分类',
          align: "center",
          dataIndex: 'processParametersCategory',
          scopedSlots: {
            customRender: 'processParametersCategory'
          },
        },
        {
          title: '计量单位',
          align: "center",
          dataIndex: 'unit',
          scopedSlots: {
            customRender: 'unit'
          },
        },
        {
          title: '操作',
          align: 'center',
          dataIndex: 'action',
          scopedSlots: {
            customRender: 'action'
          },
        }
      ],
      title: "操作",
      visible: false,
      visible4Confirm: false,
      disableSubmit: false,
      codeDisable: true,
      model: {},
      labelCol: {
        xs: { span: 24 },
        sm: { span: 8 },
      },
      wrapperCol: {
        xs: { span: 24 },
        sm: { span: 16 },
      },
      confirmLoading: false,
      form: this.$form.createForm(this),
      validatorRules: {
        num: {
          rules: [
            { required: true, message: '请输入工艺参数模板编码!' },
            { min: 0, max: 30, message: '最长 30 个字符', trigger: 'blur' },
            { validator: this.validateNum },
          ]
        },
        name: {
          rules: [
            { required: true, message: '请输入工艺参数模板名称!' },
            { min: 0, max: 100, message: '最长 100 个字符', trigger: 'blur' },
            { validator: this.validateName },
          ]
        },
      },
      url: {
        add: "/eam/processParametersTemplate/add",
        edit: "/eam/processParametersTemplate/edit",
        loadTree: "/eam/processParameters/loadTree",
      },
      treeData: [],
      TemplateDetailDataSource: [],
      allProcessParametersList: [],
      dataSource: [],
    }
  },

  mounted() {
    this.$bus.$on('selectionRows', (data) => {
      for (let i = 0; i < data.length; i++) {
        this.dataSource.push({
          id: data[i].id,
          processParametersNum: data[i].num,
          processParametersName: data[i].name,
          processParametersCategory: data[i].processParametersCategoryNumName,
          unit: data[i].unitId_dictText,
          processParametersId: data[i].id,
        })
      }
    })
  },

  methods: {

    //选择工艺参数
    selectProcessParameters: function () {
      let ids = [];
      for (let i = 0; i < this.dataSource.length; i++) {
        ids.push(this.dataSource[i].processParametersId);
      }
      this.$refs.processParametersModalForm.showModal(ids);
      this.$refs.processParametersModalForm.title = '选择工艺参数';
      this.$refs.processParametersModalForm.disableSubmit = false;
    },

    add() {
      this.edit({ processParametersTemplateDetail: [] })
    },

    edit(record) {
      let that = this;
      that.dataSource = [];
      this.form.resetFields();
      this.model = Object.assign({}, record);
      this.visible = true;
      if (record.processParametersTemplateDetailList!= undefined) {
        const temp = [...record.processParametersTemplateDetailList];
        that.dataSource = temp;
      }
      that.$nextTick(() => {
        that.form.setFieldsValue(pick(that.model, 'num', 'name', 'remark'));
      });
      if (record.id) {
        this.codeDisable = true;
      } else {
        this.codeDisable = false;
      }
    },

     close() {
      this.$emit('close');
      this.visible = false;
    },

    handleCancel() {
      this.close();
    },

    handleOk() {
      const that = this;

      //触发表单验证
      this.form.validateFields((err, values) => {
        if (!err) {
          that.confirmLoading = true;
          let formData = Object.assign(this.model, values);

          formData.ProcessParametersTemplateDetailList = that.dataSource;

          if (that.dataSource.length ===0){
            that.confirmLoading = false
            that.$message.warning("请添加工艺参数模板明细")
            return
          }
            let obj;
            if (!this.model.id) {
              obj = postAction(this.url.add, formData);
            } else {
              obj = requestPut(this.url.edit, formData, { id: this.model.id });
            }
            obj.then((res) => {
              if (res.success) {
                that.$message.success(res.message);
                that.$emit('ok');
              } else {
                that.$message.warning(res.message);
              }
            }).finally(() => {
              that.confirmLoading = false;
              that.close();
            })

          }

      })
    },

    handleDelete(record, index) {
      this.dataSource.splice(index, 1);
    },

    //验证 工艺参数模板编码
    validateNum(rule, value, callback) {
      var params = {
        tableName: 'mom_eam_process_parameters_template',
        fieldName: 'num',
        fieldVal: value,
        dataId: this.model.id,
        //数据库中存在字段del_flag并使用该字段作为未删除策略，真删除：false 假删除：true
        delFlag: 'true',
      };
      duplicateCheck(params).then((res) => {
        if (res.success) {
          callback();
        } else {
          callback("工艺参数模板编码已存在!");
        }
      })
    },

  },
}
</script>

<style lang="less" scoped>
/deep/ .frozenRowClass {
  color: #c9c9c9;
}
.fontweight {
  font-weight: bold;
}
.ant-btn {
  padding: 0 10px;
  margin-left: 3px;
}

.ant-form-item-control {
  line-height: 0px;
}

/** 主表单行间距 */
.ant-form .ant-form-item {
  margin-bottom: 10px;
}

/** Tab页面行间距 */
.ant-tabs-content .ant-form-item {
  margin-bottom: 0px;
}
</style>